# Changelog

## 0.5.0 (12.06.2023)

* **New**: Add support for single-part content

## 0.4.0 (30.05.2023)

* **New**: Added a version command to the CLI
* **New**: Ensure external links open in new tabs

## 0.2.2 (18.04.2023)

* **Update**: Various accessibility improvements

## 0.2.1 (08.03.2023)

* **New**: Added sphinxcontrib-mermaid dependency
* **Update**: Updated sphinx-book-theme to >=1.0.0,<2.0.0
